@@ -4,14 +4,17 @@ import re
 
 from lunr.pipeline import Pipeline
 
+full_re = re.compile(r"^\W*?([^\W]+)\W*?$")
+
 
 def trimmer(token, i=None, tokens=None):
     def trim(s, metadata=None):
-        s = re.sub(r'^\W+', '', s)
-        s = re.sub(r'\W+$', '', s)
-        return s
+        match = full_re.match(s)
+        if match is None:
+            return s
+        return match.group(1)
 
     return token.update(trim)
 
 
-Pipeline.register_function(trimmer, 'trimmer')
+Pipeline.register_function(trimmer, "trimmer")
